@@ -32,7 +32,7 @@ from ...modelstate import ModelState
 #
 class Chain:
     def __init__(self, elements: typing.Sequence[Element]) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
         self.elements: typing.Sequence[Element] = elements
 
     def process(self, context: mango.Context, model_state: ModelState) -> typing.Sequence[mango.Order]:
@@ -47,6 +47,6 @@ class Chain:
     def __str__(self) -> str:
         elements = "\n    ".join(map(str, self.elements)) or "None"
 
-        return f"""« 𝙲𝚑𝚊𝚒𝚗 of {len(self.elements)} elements:
+        return f"""« Chain of {len(self.elements)} elements:
     {elements}
 »"""
